@@ -3,7 +3,7 @@ function(x, dist.print=FALSE, digits=2, ...)
 {
 # Display of the distances between groups (optional)
 if (dist.print) 
-  {cat("distances between group\n") 
+  {cat("distances between groups\n") 
    print(x$distances, digits=digits, ...)
   }
 print(x$clust)
